@@ -21,7 +21,7 @@ typedef char *address;
 typedef short int shortint;
 typedef float real;
 typedef double doublereal;
-typedef struct { real r, i; } complex;
+typedef struct { real r, i; } singlecomplex;
 typedef struct { doublereal r, i; } doublecomplex;
 typedef short int shortlogical;
 typedef char logical1;
