@@ -103,7 +103,7 @@ int cfgmr(int n,
 +-----------------------------------------------------------------------
 | subroutines called :
 | matvec - matrix-vector multiplication operation
-| psolve - (right) preconditionning operation
+| psolve - (right) preconditioning operation
 |	   psolve can be a NULL pointer (GMRES without preconditioner)
 +---------------------------------------------------------------------*/
 
@@ -116,10 +116,6 @@ int cfgmr(int n,
     singlecomplex one = {1.0, 0.0};
     singlecomplex tt1, tt2;
 
-    /* prototypes */
-    extern int ccopy_(int *, singlecomplex *, int *, singlecomplex *, int *);
-    extern int caxpy_(int *, singlecomplex *, singlecomplex [], int *, singlecomplex [], int *);
-
     its = 0;
     vv = (singlecomplex **)SUPERLU_MALLOC((im + 1) * sizeof(singlecomplex *));
     for (int i = 0; i <= im; i++) vv[i] = singlecomplexMalloc(n);
@@ -239,7 +235,7 @@ int cfgmr(int n,
 	            cs_mult(&vv[i1][k], &vv[i1][k], t);
 	    }
 	    /*---------------------------------------------------
-	    |     done with modified gram schimdt and arnoldi step
+	    |     done with modified gram schmidt and arnoldi step
 	    |     now  update factorization of hh
 	    +--------------------------------------------------*/
 
