@@ -15,7 +15,7 @@ at the top-level directory.
  * -- SuperLU routine (version 4.0) --
  * Lawrence Berkeley National Laboratory
  * June 1, 2009
- * <\pre>
+ * </pre>
  */
 #include "slu_ddefs.h"
 
@@ -29,16 +29,16 @@ at the top-level directory.
  */
 int mark_relax(
 	int n,		    /* order of the matrix A */
-	int *relax_end,     /* last column in a relaxed supernode.
+	const int *relax_end,     /* last column in a relaxed supernode.
 			     * if j-th column starts a relaxed supernode,
 			     * relax_end[j] represents the last column of
 			     * this supernode. */
-	int *relax_fsupc,   /* first column in a relaxed supernode.
+	const int *relax_fsupc,   /* first column in a relaxed supernode.
 			     * relax_fsupc[j] represents the first column of
 			     * j-th supernode. */
-	int_t *xa_begin,    /* Astore->colbeg */
-	int_t *xa_end,	    /* Astore->colend */
-	int_t *asub,	    /* row index of A */
+	const int_t *xa_begin,    /* Astore->colbeg */
+	const int_t *xa_end,	    /* Astore->colend */
+	const int_t *asub,	    /* row index of A */
 	int   *marker	    /* marker[j] is the maximum column index if j-th
 			     * row belongs to a relaxed supernode. */ )
 {
@@ -46,7 +46,7 @@ int mark_relax(
     register int_t i, j;
     int_t k;
 
-    for (i = 0; i < n && relax_fsupc[i] != EMPTY; i++)
+    for (i = 0; i < n && relax_fsupc[i] != SLU_EMPTY; i++)
     {
 	jcol = relax_fsupc[i];	/* first column */
 	kcol = relax_end[jcol]; /* last column */
