@@ -13,14 +13,15 @@ at the top-level directory.
  * \brief Header file for real operations
  * 
  * <pre> 
- * -- SuperLU routine (version 4.1) --
+ * -- SuperLU routine (version 7.0.0) --
  * Univ. of California Berkeley, Xerox Palo Alto Research Center,
  * and Lawrence Berkeley National Lab.
  * November, 2010
+ * August 2024
  * 
  * Global data structures used in LU factorization -
  * 
- *   nsuper: #supernodes = nsuper + 1, numbered [0, nsuper].
+ *   nsuper: \#supernodes = nsuper + 1, numbered [0, nsuper].
  *   (xsup,supno): supno[i] is the supernode no to which i belongs;
  *	xsup(s) points to the beginning of the s-th supernode.
  *	e.g.   supno 0 1 2 2 3 3 3 4 4 4 4 4   (n=12)
@@ -54,7 +55,7 @@ at the top-level directory.
  *	values.
  *
  *	The last column structures (for pruning) will be removed
- *	after the numercial LU factorization phase.
+ *	after the numerical LU factorization phase.
  *
  *   (xlusup,lusup): lusup[*] contains the numerical values of the
  *	rectangular supernodes; xlusup[j] points to the starting
@@ -126,76 +127,76 @@ cgsisx(superlu_options_t *options, SuperMatrix *A, int *perm_c, int *perm_r,
 
 /*! \brief Supernodal LU factor related */
 extern void
-cCreate_CompCol_Matrix(SuperMatrix *, int, int, int_t, complex *,
+cCreate_CompCol_Matrix(SuperMatrix *, int, int, int_t, singlecomplex *,
 		       int_t *, int_t *, Stype_t, Dtype_t, Mtype_t);
 extern void
-cCreate_CompRow_Matrix(SuperMatrix *, int, int, int_t, complex *,
+cCreate_CompRow_Matrix(SuperMatrix *, int, int, int_t, singlecomplex *,
 		       int_t *, int_t *, Stype_t, Dtype_t, Mtype_t);
-extern void cCompRow_to_CompCol(int, int, int_t, complex*, int_t*, int_t*,
-		                   complex **, int_t **, int_t **);
+extern void cCompRow_to_CompCol(int, int, int_t, singlecomplex*, int_t*, int_t*,
+		                   singlecomplex **, int_t **, int_t **);
 extern void
 cCopy_CompCol_Matrix(SuperMatrix *, SuperMatrix *);
 extern void
-cCreate_Dense_Matrix(SuperMatrix *, int, int, complex *, int,
+cCreate_Dense_Matrix(SuperMatrix *, int, int, singlecomplex *, int,
 		     Stype_t, Dtype_t, Mtype_t);
 extern void
-cCreate_SuperNode_Matrix(SuperMatrix *, int, int, int_t, complex *, 
+cCreate_SuperNode_Matrix(SuperMatrix *, int, int, int_t, singlecomplex *, 
 		         int_t *, int_t *, int_t *, int *, int *,
 			 Stype_t, Dtype_t, Mtype_t);
 extern void
-cCopy_Dense_Matrix(int, int, complex *, int, complex *, int);
+cCopy_Dense_Matrix(int, int, singlecomplex *, int, singlecomplex *, int);
 
-extern void    callocateA (int, int_t, complex **, int_t **, int_t **);
+extern void    callocateA (int, int_t, singlecomplex **, int_t **, int_t **);
 extern void    cgstrf (superlu_options_t*, SuperMatrix*,
                        int, int, int*, void *, int_t, int *, int *, 
                        SuperMatrix *, SuperMatrix *, GlobalLU_t *,
 		       SuperLUStat_t*, int_t *info);
 extern int_t   csnode_dfs (const int, const int, const int_t *, const int_t *,
 			     const int_t *, int_t *, int *, GlobalLU_t *);
-extern int     csnode_bmod (const int, const int, const int, complex *,
-                              complex *, GlobalLU_t *, SuperLUStat_t*);
+extern int     csnode_bmod (const int, const int, const int, singlecomplex *,
+                              singlecomplex *, GlobalLU_t *, SuperLUStat_t*);
 extern void    cpanel_dfs (const int, const int, const int, SuperMatrix *,
-			   int *, int *, complex *, int *, int *, int *,
+			   int *, int *, singlecomplex *, int *, int *, int *,
 			   int_t *, int *, int *, int_t *, GlobalLU_t *);
 extern void    cpanel_bmod (const int, const int, const int, const int,
-                           complex *, complex *, int *, int *,
+                           singlecomplex *, singlecomplex *, int *, int *,
 			   GlobalLU_t *, SuperLUStat_t*);
 extern int     ccolumn_dfs (const int, const int, int *, int *, int *, int *,
 			   int *, int_t *, int *, int *, int_t *, GlobalLU_t *);
-extern int     ccolumn_bmod (const int, const int, complex *,
-			   complex *, int *, int *, int,
+extern int     ccolumn_bmod (const int, const int, singlecomplex *,
+			   singlecomplex *, int *, int *, int,
                            GlobalLU_t *, SuperLUStat_t*);
 extern int     ccopy_to_ucol (int, int, int *, int *, int *,
-                              complex *, GlobalLU_t *);         
+                              singlecomplex *, GlobalLU_t *);         
 extern int     cpivotL (const int, const double, int *, int *, 
                          int *, int *, int *, GlobalLU_t *, SuperLUStat_t*);
 extern void    cpruneL (const int, const int *, const int, const int,
 			  const int *, const int *, int_t *, GlobalLU_t *);
-extern void    creadmt (int *, int *, int_t *, complex **, int_t **, int_t **);
-extern void    cGenXtrue (int, int, complex *, int);
-extern void    cFillRHS (trans_t, int, complex *, int, SuperMatrix *,
+extern void    creadmt (int *, int *, int_t *, singlecomplex **, int_t **, int_t **);
+extern void    cGenXtrue (int, int, singlecomplex *, int);
+extern void    cFillRHS (trans_t, int, singlecomplex *, int, SuperMatrix *,
 			  SuperMatrix *);
-extern void    cgstrs (trans_t, SuperMatrix *, SuperMatrix *, int *, int *,
+extern void    cgstrs (trans_t, SuperMatrix *, SuperMatrix *, const int *, const int *,
                         SuperMatrix *, SuperLUStat_t*, int *);
 /* ILU */
 extern void    cgsitrf (superlu_options_t*, SuperMatrix*, int, int, int*,
 		        void *, int_t, int *, int *, SuperMatrix *, SuperMatrix *,
                         GlobalLU_t *, SuperLUStat_t*, int_t *info);
-extern int     cldperm(int, int, int_t, int_t [], int_t [], complex [],
+extern int     cldperm(int, int, int_t, int_t [], int_t [], singlecomplex [],
                         int [],	float [], float []);
 extern int     ilu_csnode_dfs (const int, const int, const int_t *, const int_t *,
 			       const int_t *, int *, GlobalLU_t *);
 extern void    ilu_cpanel_dfs (const int, const int, const int, SuperMatrix *,
-			       int *, int *, complex *, float *, int *, int *,
+			       int *, int *, singlecomplex *, float *, int *, int *,
 			       int *, int *, int *, int_t *, GlobalLU_t *);
 extern int     ilu_ccolumn_dfs (const int, const int, int *, int *, int *,
 				int *, int *, int *, int *, int_t *, GlobalLU_t *);
 extern int     ilu_ccopy_to_ucol (int, int, int *, int *, int *,
-                                  complex *, int, milu_t, double, int,
-                                  complex *, int *, GlobalLU_t *, float *);
+                                  singlecomplex *, int, milu_t, double, int,
+                                  singlecomplex *, int *, GlobalLU_t *, float *);
 extern int     ilu_cpivotL (const int, const double, int *, int *, int, int *,
 			    int *, int *, int *, double, milu_t,
-                            complex, GlobalLU_t *, SuperLUStat_t*);
+                            singlecomplex, GlobalLU_t *, SuperLUStat_t*);
 extern int     ilu_cdrop_row (superlu_options_t *, int, int, double,
                               int, int *, double *, GlobalLU_t *, 
                               float *, float *, int);
@@ -217,38 +218,39 @@ extern void    cgsrfs (trans_t, SuperMatrix *, SuperMatrix *,
                        float *, float *, SuperLUStat_t*, int *);
 
 extern int     sp_ctrsv (char *, char *, char *, SuperMatrix *,
-			SuperMatrix *, complex *, SuperLUStat_t*, int *);
-extern int     sp_cgemv (char *, complex, SuperMatrix *, complex *,
-			int, complex, complex *, int);
+			SuperMatrix *, singlecomplex *, SuperLUStat_t*, int *);
+extern int     sp_cgemv (char *, singlecomplex, SuperMatrix *, singlecomplex *,
+			int, singlecomplex, singlecomplex *, int);
 
-extern int     sp_cgemm (char *, char *, int, int, int, complex,
-			SuperMatrix *, complex *, int, complex, 
-			complex *, int);
+extern int     sp_cgemm (char *, char *, int, int, int, singlecomplex,
+			SuperMatrix *, singlecomplex *, int, singlecomplex, 
+			singlecomplex *, int);
 extern         float smach(char *);   /* from C99 standard, in float.h */
 
 /*! \brief Memory-related */
 extern int_t   cLUMemInit (fact_t, void *, int_t, int, int, int_t, int,
                             float, SuperMatrix *, SuperMatrix *,
-                            GlobalLU_t *, int **, complex **);
-extern void    cSetRWork (int, int, complex *, complex **, complex **);
-extern void    cLUWorkFree (int *, complex *, GlobalLU_t *);
+                            GlobalLU_t *, int **, singlecomplex **);
+extern void    cSetRWork (int, int, singlecomplex *, singlecomplex **, singlecomplex **);
+extern void    cLUWorkFree (int *, singlecomplex *, GlobalLU_t *);
 extern int_t   cLUMemXpand (int, int_t, MemType, int_t *, GlobalLU_t *);
 
-extern complex  *complexMalloc(size_t);
-extern complex  *complexCalloc(size_t);
-extern float  *floatMalloc(int);
-extern float  *floatCalloc(int);
+extern singlecomplex  *singlecomplexMalloc(size_t);
+extern singlecomplex  *singlecomplexCalloc(size_t);
+extern float  *floatMalloc(size_t);
+extern float  *floatCalloc(size_t);
 extern int_t   cmemory_usage(const int_t, const int_t, const int_t, const int);
 extern int     cQuerySpace (SuperMatrix *, SuperMatrix *, mem_usage_t *);
 extern int     ilu_cQuerySpace (SuperMatrix *, SuperMatrix *, mem_usage_t *);
 
 /*! \brief Auxiliary routines */
-extern void    creadhb(FILE *, int *, int *, int_t *, complex **, int_t **, int_t **);
-extern void    creadrb(int *, int *, int_t *, complex **, int_t **, int_t **);
-extern void    creadtriple(int *, int *, int_t *, complex **, int_t **, int_t **);
-extern void    creadMM(FILE *, int *, int *, int_t *, complex **, int_t **, int_t **);
-extern void    cfill (complex *, int, complex);
-extern void    cinf_norm_error (int, SuperMatrix *, complex *);
+extern void    creadhb(FILE *, int *, int *, int_t *, singlecomplex **, int_t **, int_t **);
+extern void    creadrb(int *, int *, int_t *, singlecomplex **, int_t **, int_t **);
+extern void    creadtriple(int *, int *, int_t *, singlecomplex **, int_t **, int_t **);
+extern void    creadtriple_noheader(int *, int *, int_t *, singlecomplex **, int_t **, int_t **);
+extern void    creadMM(FILE *, int *, int *, int_t *, singlecomplex **, int_t **, int_t **);
+extern void    cfill (singlecomplex *, int, singlecomplex);
+extern void    cinf_norm_error (int, SuperMatrix *, singlecomplex *);
 extern float  sqselect(int, float *, int);
 
 
@@ -257,24 +259,26 @@ extern void    cPrint_CompCol_Matrix(char *, SuperMatrix *);
 extern void    cPrint_SuperNode_Matrix(char *, SuperMatrix *);
 extern void    cPrint_Dense_Matrix(char *, SuperMatrix *);
 extern void    cprint_lu_col(char *, int, int, int_t *, GlobalLU_t *);
-extern int     print_double_vec(char *, int, double *);
-extern void    ccheck_tempv(int, complex *);
+extern int     print_singlecomplex_vec(const char *, int, const singlecomplex *);
+extern void    ccheck_tempv(int, singlecomplex *);
 
 /*! \brief BLAS */
 
-extern int cgemm_(const char*, const char*, const int*, const int*, const int*,
-                  const complex*, const complex*, const int*, const complex*,
-		  const int*, const complex*, complex*, const int*);
-extern int ctrsv_(char*, char*, char*, int*, complex*, int*,
-                  complex*, int*);
-extern int ctrsm_(char*, char*, char*, char*, int*, int*,
-                  complex*, complex*, int*, complex*, int*);
-extern int cgemv_(char *, int *, int *, complex *, complex *a, int *,
-                  complex *, int *, complex *, complex *, int *);
+extern void ccopy_(int *, singlecomplex *, int *, singlecomplex *, int *);
+extern void caxpy_(int *, singlecomplex *, singlecomplex *, int *, singlecomplex *, int *);
+extern void cgemm_(const char*, const char*, const int*, const int*, const int*,
+                  const singlecomplex*, const singlecomplex*, const int*, const singlecomplex*,
+		  const int*, const singlecomplex*, singlecomplex*, const int*);
+extern void ctrsv_(char*, char*, char*, int*, singlecomplex*, int*,
+                  singlecomplex*, int*);
+extern void ctrsm_(char*, char*, char*, char*, int*, int*,
+                  singlecomplex*, singlecomplex*, int*, singlecomplex*, int*);
+extern void cgemv_(char *, int *, int *, singlecomplex *, singlecomplex *a, int *,
+                  singlecomplex *, int *, singlecomplex *, singlecomplex *, int *);
 
-extern void cusolve(int, int, complex*, complex*);
-extern void clsolve(int, int, complex*, complex*);
-extern void cmatvec(int, int, int, complex*, complex*, complex*);
+extern void cusolve(int, int, singlecomplex*, singlecomplex*);
+extern void clsolve(int, int, singlecomplex*, singlecomplex*);
+extern void cmatvec(int, int, int, singlecomplex*, singlecomplex*, singlecomplex*);
 
 #ifdef __cplusplus
   }
