@@ -51,24 +51,24 @@ at the top-level directory.
  * </pre>
  */
 
-int
+int_t
 ssnode_dfs (
-	   const int  jcol,	    /* in - start of the supernode */
-	   const int  kcol, 	    /* in - end of the supernode */
-	   const int  *asub,        /* in */
-	   const int  *xa_begin,    /* in */
-	   const int  *xa_end,      /* in */
-	   int        *xprune,      /* out */
+	   const int   jcol,	    /* in - start of the supernode */
+	   const int   kcol, 	    /* in - end of the supernode */
+	   const int_t *asub,        /* in */
+	   const int_t *xa_begin,    /* in */
+	   const int_t *xa_end,      /* in */
+	   int_t      *xprune,      /* out */
 	   int        *marker,      /* modified */
 	   GlobalLU_t *Glu          /* modified */
 	   )
 {
 
-    register int i, k, ifrom, ito, nextl, new_next;
-    int          nsuper, krow, kmark, mem_error;
-    int          *xsup, *supno;
-    int          *lsub, *xlsub;
-    int          nzlmax;
+    int_t i, k, ifrom, ito, nextl, new_next, nzlmax;
+    int   nsuper, krow, kmark;
+    int_t mem_error;
+    int   *xsup, *supno;
+    int_t *lsub, *xlsub;
     
     xsup    = Glu->xsup;
     supno   = Glu->supno;
