@@ -1,34 +1,32 @@
 /*  -- translated by f2c (version 19940927).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
 */
 
+#include <math.h>
+#include <stdbool.h>
+#include <stdlib.h>
 #include <string.h>
-#include "f2c.h"
+#include "../../SRC/slu_sdefs.h"
 
 /* Table of constant values */
 
-/* Subroutine */ int clatb4_slu(char *path, integer *imat, integer *m, integer *
-	n, char *type, integer *kl, integer *ku, real *anorm, integer *mode, 
-	real *cndnum, char *dist)
+/* Subroutine */ int clatb4_slu(char *path, int *imat, int *m, int *
+	n, char *type, int *kl, int *ku, float *anorm, int *mode,
+	float *cndnum, char *dist)
 {
     /* Initialized data */
 
-    static logical first = TRUE_;
+    static bool first = true;
 
     /* System generated locals */
-    integer i__1;
-
-    /* Builtin functions */
-    double sqrt(doublereal);
+    int i__1;
 
     /* Local variables */
-    static real badc1, badc2, large, small;
+    static float badc1, badc2, large, small;
     static char c2[2];
-    extern /* Subroutine */ int slabad_slu(real *, real *);
+    extern /* Subroutine */ int slabad_slu(float *, float *);
     extern float smach(char *);
-    static integer mat;
-    static real eps;
+    static int mat;
+    static float eps;
 
 
 /*  -- LAPACK test routine (version 2.0) --   
@@ -95,7 +93,7 @@
        Set some constants for use in the subroutine. */
 
     if (first) {
-	first = FALSE_;
+	first = false;
 	eps = smach("Precision");
 	badc2 = .1f / eps;
 	badc1 = sqrt(badc2);
@@ -137,19 +135,19 @@
 	    *kl = 0;
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	} else if (*imat == 3) {
 /* Computing MAX */
 	    i__1 = *m - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 	    *ku = 0;
 	} else {
 /* Computing MAX */
 	    i__1 = *m - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	}
 
 /*        Set the condition number and norm. */
@@ -187,19 +185,19 @@
 	    *kl = 0;
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	} else if (*imat == 3) {
 /* Computing MAX */
 	    i__1 = *m - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 	    *ku = 0;
 	} else {
 /* Computing MAX */
 	    i__1 = *m - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	}
 
 /*        Set the condition number and norm. */
@@ -301,7 +299,7 @@ x.
 	} else {
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 	}
 	*ku = *kl;
 
@@ -398,13 +396,13 @@ te
 	} else if (*imat < 0) {
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 	    *ku = 0;
 	} else {
 	    *kl = 0;
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	}
 
 /*        Set the condition number and norm. */
