@@ -3,6 +3,8 @@
 
 #include "../../SRC/slu_ddefs.h"
 
+#include <math.h>
+
 /* Table of constant values */
 
 static int c__3 = 3;
@@ -18,19 +20,13 @@ static double c_b13 = 0.;
     int a_dim1, a_offset, i__1, i__2, i__3;
     double d__1;
 
-    /* Builtin functions */
-    double d_sign(double *, double *);
-
     /* Local variables */
     extern /* Subroutine */ int dger_(int *, int *, double *,
 	    double *, int *, double *, int *, double *,
 	    int *);
     extern double dnrm2_(int *, double *, int *);
     static int i, j;
-    extern /* Subroutine */ int dscal_(int *, double *, double *,
-	    int *), dgemv_(char *, int *, int *, double *,
-	    double *, int *, double *, int *, double *,
-	    double *, int *);
+    extern /* Subroutine */ int dscal_(int *, double *, double *, int *);
     static double wa, wb, wn;
     extern /* Subroutine */ int dlarnv_slu(int *, int *, int *, double *);
     extern int input_error(char *, int *);
@@ -152,7 +148,7 @@ static double c_b13 = 0.;
 	    dlarnv_slu(&c__3, &iseed[1], &i__1, &work[1]);
 	    i__1 = *m - i + 1;
 	    wn = dnrm2_(&i__1, &work[1], &c__1);
-	    wa = d_sign(&wn, &work[1]);
+	    wa = copysign(wn, work[1]);
 	    if (wn == 0.) {
 		tau = 0.;
 	    } else {
@@ -185,7 +181,7 @@ t */
 	    dlarnv_slu(&c__3, &iseed[1], &i__1, &work[1]);
 	    i__1 = *n - i + 1;
 	    wn = dnrm2_(&i__1, &work[1], &c__1);
-	    wa = d_sign(&wn, &work[1]);
+	    wa = copysign(wn, work[1]);
 	    if (wn == 0.) {
 		tau = 0.;
 	    } else {
@@ -234,7 +230,7 @@ L = 0)
 
 		i__2 = *m - *kl - i + 1;
 		wn = dnrm2_(&i__2, &a[*kl + i + i * a_dim1], &c__1);
-		wa = d_sign(&wn, &a[*kl + i + i * a_dim1]);
+		wa = copysign(wn, a[*kl + i + i * a_dim1]);
 		if (wn == 0.) {
 		    tau = 0.;
 		} else {
@@ -271,7 +267,7 @@ eft */
 
 		i__2 = *n - *ku - i + 1;
 		wn = dnrm2_(&i__2, &a[i + (*ku + i) * a_dim1], lda);
-		wa = d_sign(&wn, &a[i + (*ku + i) * a_dim1]);
+		wa = copysign(wn, a[i + (*ku + i) * a_dim1]);
 		if (wn == 0.) {
 		    tau = 0.;
 		} else {
@@ -313,7 +309,7 @@ ight */
 
 		i__2 = *n - *ku - i + 1;
 		wn = dnrm2_(&i__2, &a[i + (*ku + i) * a_dim1], lda);
-		wa = d_sign(&wn, &a[i + (*ku + i) * a_dim1]);
+		wa = copysign(wn, a[i + (*ku + i) * a_dim1]);
 		if (wn == 0.) {
 		    tau = 0.;
 		} else {
@@ -350,7 +346,7 @@ ight */
 
 		i__2 = *m - *kl - i + 1;
 		wn = dnrm2_(&i__2, &a[*kl + i + i * a_dim1], &c__1);
-		wa = d_sign(&wn, &a[*kl + i + i * a_dim1]);
+		wa = copysign(wn, a[*kl + i + i * a_dim1]);
 		if (wn == 0.) {
 		    tau = 0.;
 		} else {
