@@ -17,19 +17,13 @@ static double c_b10 = 0.;
     int a_dim1, a_offset, i__1;
     double d__1;
 
-    /* Builtin functions */
-    double d_sign(double *, double *);
-
     /* Local variables */
     extern /* Subroutine */ int dger_(int *, int *, double *,
 	    double *, int *, double *, int *, double *,
 	    int *);
     extern double dnrm2_(int *, double *, int *);
     static int i;
-    extern /* Subroutine */ int dscal_(int *, double *, double *,
-	    int *), dgemv_(char *, int *, int *, double *,
-	    double *, int *, double *, int *, double *,
-	    double *, int *);
+    extern /* Subroutine */ int dscal_(int *, double *, double *, int *);
     static double wa, wb, wn;
     extern /* Subroutine */ int dlarnv_slu(int *, int *, int *, double *);
     extern int input_error(char *, int *);
@@ -111,7 +105,7 @@ static double c_b10 = 0.;
 	dlarnv_slu(&c__3, &iseed[1], &i__1, &work[1]);
 	i__1 = *n - i + 1;
 	wn = dnrm2_(&i__1, &work[1], &c__1);
-	wa = d_sign(&wn, &work[1]);
+	wa = copysign(wn, work[1]);
 	if (wn == 0.) {
 	    tau = 0.;
 	} else {
