@@ -2,6 +2,8 @@
 */
 #include "../../SRC/slu_sdefs.h"
 
+#include <math.h>
+
 /* Table of constant values */
 
 static int c__3 = 3;
@@ -17,9 +19,6 @@ static float c_b26 = 1.f;
     int a_dim1, a_offset, i__1, i__2, i__3;
     float r__1;
 
-    /* Builtin functions */
-    double r_sign(float *, float *);
-
     /* Local variables */
     extern /* Subroutine */ int sger_(int *, int *, float *, float *,
 	    int *, float *, int *, float *, int *);
@@ -30,10 +29,7 @@ static float c_b26 = 1.f;
 	    int *, float *, int *, float *, int *);
     static float alpha;
     extern /* Subroutine */ int sscal_(int *, float *, float *, int *),
-	    sgemv_(char *, int *, int *, float *, float *, int *,
-	    float *, int *, float *, float *, int *), saxpy_(
-	    int *, float *, float *, int *, float *, int *), ssymv_(
-	    char *, int *, float *, float *, int *, float *, int *,
+	    ssymv_(char *, int *, float *, float *, int *, float *, int *,
 	    float *, float *, int *);
     static float wa, wb, wn;
     extern /* Subroutine */ int slarnv_slu(int *, int *, int *, float *);
@@ -146,7 +142,7 @@ static float c_b26 = 1.f;
 	slarnv_slu(&c__3, &iseed[1], &i__1, &work[1]);
 	i__1 = *n - i + 1;
 	wn = snrm2_(&i__1, &work[1], &c__1);
-	wa = r_sign(&wn, &work[1]);
+	wa = copysignf(wn, work[1]);
 	if (wn == 0.f) {
 	    tau = 0.f;
 	} else {
@@ -192,7 +188,7 @@ static float c_b26 = 1.f;
 
 	i__2 = *n - *k - i + 1;
 	wn = snrm2_(&i__2, &a[*k + i + i * a_dim1], &c__1);
-	wa = r_sign(&wn, &a[*k + i + i * a_dim1]);
+	wa = copysignf(wn, a[*k + i + i * a_dim1]);
 	if (wn == 0.f) {
 	    tau = 0.f;
 	} else {
