@@ -1,62 +1,59 @@
 /*  -- translated by f2c (version 19940927).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
 */
+#include <math.h>
+#include <stdbool.h>
+#include <stdlib.h>
 #include <string.h>
-#include "f2c.h"
+#include "../../SRC/slu_sdefs.h"
 
 /* Table of constant values */
 
-static integer c__1 = 1;
-static real c_b22 = 0.f;
-static logical c_true = TRUE_;
-static logical c_false = FALSE_;
+static int c__1 = 1;
+static float c_b22 = 0.f;
+static bool c_true = true;
+static bool c_false = false;
 
-/* Subroutine */ int slatms_slu(integer *m, integer *n, char *dist, integer *
-	iseed, char *sym, real *d, integer *mode, real *cond, real *dmax__, 
-	integer *kl, integer *ku, char *pack, real *a, integer *lda, real *
-	work, integer *info)
+/* Subroutine */ int slatms_slu(int *m, int *n, char *dist, int *
+	iseed, char *sym, float *d, int *mode, float *cond, float *dmax__,
+	int *kl, int *ku, char *pack, float *a, int *lda, float *
+	work, int *info)
 {
     /* System generated locals */
-    integer a_dim1, a_offset, i__1, i__2, i__3, i__4, i__5, i__6;
-    real r__1, r__2, r__3;
-    logical L__1;
-
-    /* Builtin functions */
-    double cos(doublereal), sin(doublereal);
+    int a_dim1, a_offset, i__1, i__2, i__3, i__4, i__5, i__6;
+    float r__1, r__2, r__3;
+    bool L__1;
 
     /* Local variables */
-    static integer ilda, icol;
-    static real temp;
-    static integer irow, isym;
-    static real c;
-    static integer i, j, k;
-    static real s, alpha, angle;
-    static integer ipack, ioffg;
-    static integer iinfo;
-    extern /* Subroutine */ int sscal_(integer *, real *, real *, integer *);
-    static integer idist, mnmin, iskew;
-    static real extra, dummy;
-    extern /* Subroutine */ int scopy_(integer *, real *, integer *, real *, 
-	    integer *), slatm1_slu(integer *, real *, integer *, integer *, 
-	    integer *, real *, integer *, integer *);
-    static integer ic, jc, nc, il, iendch, ir, jr, ipackg, mr;
-    extern /* Subroutine */ int slagge_slu(integer *, integer *, integer *, 
-	    integer *, real *, real *, integer *, integer *, real *, integer *
+    static int ilda, icol;
+    static float temp;
+    static int irow, isym;
+    static float c;
+    static int i, j, k;
+    static float s, alpha, angle;
+    static int ipack, ioffg;
+    static int iinfo;
+    extern /* Subroutine */ int sscal_(int *, float *, float *, int *);
+    static int idist, mnmin, iskew;
+    static float extra, dummy;
+    extern int slatm1_slu(int *, float *, int *, int *,
+	    int *, float *, int *, int *);
+    static int ic, jc, nc, il, iendch, ir, jr, ipackg, mr;
+    extern /* Subroutine */ int slagge_slu(int *, int *, int *,
+	    int *, float *, float *, int *, int *, float *, int *
 	    );
-    static integer minlda;
+    static int minlda;
     extern int input_error(char *, int *);
-    extern doublereal slarnd_slu(integer *, integer *);
-    static logical iltemp, givens;
-    static integer ioffst, irsign;
-    extern /* Subroutine */ int slartg_slu(real *, real *, real *, real *, real *
-	    ), slaset_slu(char *, integer *, integer *, real *, real *, real *, 
-	    integer *), slagsy_slu(integer *, integer *, real *, real *, 
-	    integer *, integer *, real *, integer *), slarot_slu(logical *, 
-	    logical *, logical *, integer *, real *, real *, real *, integer *
-	    , real *, real *);
-    static logical ilextr, topdwn;
-    static integer ir1, ir2, isympk, jch, llb, jkl, jku, uub;
+    extern double slarnd_slu(int *, int *);
+    static bool iltemp, givens;
+    static int ioffst, irsign;
+    extern /* Subroutine */ int slartg_slu(float *, float *, float *, float *, float *
+	    ), slaset_slu(char *, int *, int *, float *, float *, float *,
+	    int *), slagsy_slu(int *, int *, float *, float *,
+	    int *, int *, float *, int *), slarot_slu(bool *,
+	    bool *, bool *, int *, float *, float *, float *, int *
+	    , float *, float *);
+    static bool ilextr, topdwn;
+    static int ir1, ir2, isympk, jch, llb, jkl, jku, uub;
 
 
 /*  -- LAPACK test routine (version 2.0) --   
@@ -399,19 +396,19 @@ static logical c_false = FALSE_;
 
 /*     Set certain internal parameters */
 
-    mnmin = min(*m,*n);
+    mnmin = SUPERLU_MIN(*m,*n);
 /* Computing MIN */
     i__1 = *kl, i__2 = *m - 1;
-    llb = min(i__1,i__2);
+    llb = SUPERLU_MIN(i__1,i__2);
 /* Computing MIN */
     i__1 = *ku, i__2 = *n - 1;
-    uub = min(i__1,i__2);
+    uub = SUPERLU_MIN(i__1,i__2);
 /* Computing MIN */
     i__1 = *m, i__2 = *n + llb;
-    mr = min(i__1,i__2);
+    mr = SUPERLU_MIN(i__1,i__2);
 /* Computing MIN */
     i__1 = *n, i__2 = *m + uub;
-    nc = min(i__1,i__2);
+    nc = SUPERLU_MIN(i__1,i__2);
 
     if (ipack == 5 || ipack == 6) {
 	minlda = uub + 1;
@@ -424,20 +421,20 @@ static logical c_false = FALSE_;
 /*     Use Givens rotation method if bandwidth small enough,   
        or if LDA is too small to store the matrix unpacked. */
 
-    givens = FALSE_;
+    givens = false;
     if (isym == 1) {
 /* Computing MAX */
 	i__1 = 1, i__2 = mr + nc;
-	if ((real) (llb + uub) < (real) max(i__1,i__2) * .3f) {
-	    givens = TRUE_;
+	if ((float) (llb + uub) < (float) SUPERLU_MAX(i__1,i__2) * .3f) {
+	    givens = true;
 	}
     } else {
 	if (llb << 1 < *m) {
-	    givens = TRUE_;
+	    givens = true;
 	}
     }
     if (*lda < *m && *lda >= minlda) {
-	givens = TRUE_;
+	givens = true;
     }
 
 /*     Set INFO if an error */
@@ -465,7 +462,7 @@ static logical c_false = FALSE_;
 		(isympk == 3 && isym == 1 && *ku > 0) ||
 		(isympk != 0 && *m != *n) ) {
 	*info = -12;
-    } else if (*lda < max(1,minlda)) {
+    } else if (*lda < SUPERLU_MAX(1,minlda)) {
 	*info = -14;
     }
 
@@ -499,22 +496,22 @@ static logical c_false = FALSE_;
 /*     Choose Top-Down if D is (apparently) increasing,   
        Bottom-Up if D is (apparently) decreasing. */
 
-    if (dabs(d[1]) <= (r__1 = d[mnmin], dabs(r__1))) {
-	topdwn = TRUE_;
+    if (fabs(d[1]) <= (r__1 = d[mnmin], fabs(r__1))) {
+	topdwn = true;
     } else {
-	topdwn = FALSE_;
+	topdwn = false;
     }
 
     if (*mode != 0 && abs(*mode) != 6) {
 
 /*        Scale by DMAX */
 
-	temp = dabs(d[1]);
+	temp = fabs(d[1]);
 	i__1 = mnmin;
 	for (i = 2; i <= i__1; ++i) {
 /* Computing MAX */
-	    r__2 = temp, r__3 = (r__1 = d[i], dabs(r__1));
-	    temp = dmax(r__2,r__3);
+	    r__2 = temp, r__3 = (r__1 = d[i], fabs(r__1));
+	    temp = fmax(r__2,r__3);
 /* L20: */
 	}
 
@@ -602,7 +599,7 @@ JKU, N )
 
    Computing MIN */
 		    i__3 = *m + jku;
-		    i__2 = min(i__3,*n) + jkl - 1;
+		    i__2 = SUPERLU_MIN(i__3,*n) + jkl - 1;
 		    for (jr = 1; jr <= i__2; ++jr) {
 			extra = 0.f;
 			angle = slarnd_slu(&c__1, &iseed[1]) * 
@@ -611,11 +608,11 @@ JKU, N )
 			s = sin(angle);
 /* Computing MAX */
 			i__3 = 1, i__4 = jr - jkl;
-			icol = max(i__3,i__4);
+			icol = SUPERLU_MAX(i__3,i__4);
 			if (jr < *m) {
 /* Computing MIN */
 			    i__3 = *n, i__4 = jr + jku;
-			    il = min(i__3,i__4) + 1 - icol;
+			    il = SUPERLU_MIN(i__3,i__4) + 1 - icol;
 			    L__1 = jr > jkl;
 			    slarot_slu(&c_true, &L__1, &c_false, &il, &c, &s, &a[
 				    jr - iskew * icol + ioffst + icol * 
@@ -636,11 +633,11 @@ JKU, N )
 			    }
 /* Computing MAX */
 			    i__4 = 1, i__5 = jch - jku;
-			    irow = max(i__4,i__5);
+			    irow = SUPERLU_MAX(i__4,i__5);
 			    il = ir + 2 - irow;
 			    temp = 0.f;
 			    iltemp = jch > jku;
-			    r__1 = -(doublereal)s;
+			    r__1 = -(double)s;
 			    slarot_slu(&c_false, &iltemp, &c_true, &il, &c, &
 				    r__1, &a[irow - iskew * ic + ioffst + ic *
 				     a_dim1], &ilda, &temp, &extra);
@@ -650,11 +647,11 @@ JKU, N )
 					c, &s, &dummy);
 /* Computing MAX */
 				i__4 = 1, i__5 = jch - jku - jkl;
-				icol = max(i__4,i__5);
+				icol = SUPERLU_MAX(i__4,i__5);
 				il = ic + 2 - icol;
 				extra = 0.f;
 				L__1 = jch > jku + jkl;
-				r__1 = -(doublereal)s;
+				r__1 = -(double)s;
 				slarot_slu(&c_true, &L__1, &c_true, &il, &c, &
 					r__1, &a[irow - iskew * icol + ioffst 
 					+ icol * a_dim1], &ilda, &extra, &
@@ -678,7 +675,7 @@ JKL, JKU
 
    Computing MIN */
 		    i__3 = *n + jkl;
-		    i__2 = min(i__3,*m) + jku - 1;
+		    i__2 = SUPERLU_MIN(i__3,*m) + jku - 1;
 		    for (jc = 1; jc <= i__2; ++jc) {
 			extra = 0.f;
 			angle = slarnd_slu(&c__1, &iseed[1]) * 
@@ -687,11 +684,11 @@ JKL, JKU
 			s = sin(angle);
 /* Computing MAX */
 			i__3 = 1, i__4 = jc - jku;
-			irow = max(i__3,i__4);
+			irow = SUPERLU_MAX(i__3,i__4);
 			if (jc < *n) {
 /* Computing MIN */
 			    i__3 = *m, i__4 = jc + jkl;
-			    il = min(i__3,i__4) + 1 - irow;
+			    il = SUPERLU_MIN(i__3,i__4) + 1 - irow;
 			    L__1 = jc > jku;
 			    slarot_slu(&c_false, &L__1, &c_false, &il, &c, &s, &
 				    a[irow - iskew * jc + ioffst + jc * 
@@ -712,11 +709,11 @@ JKL, JKU
 			    }
 /* Computing MAX */
 			    i__4 = 1, i__5 = jch - jkl;
-			    icol = max(i__4,i__5);
+			    icol = SUPERLU_MAX(i__4,i__5);
 			    il = ic + 2 - icol;
 			    temp = 0.f;
 			    iltemp = jch > jkl;
-			    r__1 = -(doublereal)s;
+			    r__1 = -(double)s;
 			    slarot_slu(&c_true, &iltemp, &c_true, &il, &c, &r__1,
 				     &a[ir - iskew * icol + ioffst + icol * 
 				    a_dim1], &ilda, &temp, &extra);
@@ -726,11 +723,11 @@ JKL, JKU
 					&c, &s, &dummy);
 /* Computing MAX */
 				i__4 = 1, i__5 = jch - jkl - jku;
-				irow = max(i__4,i__5);
+				irow = SUPERLU_MAX(i__4,i__5);
 				il = ir + 2 - irow;
 				extra = 0.f;
 				L__1 = jch > jkl + jku;
-				r__1 = -(doublereal)s;
+				r__1 = -(double)s;
 				slarot_slu(&c_false, &L__1, &c_true, &il, &c, &
 					r__1, &a[irow - iskew * icol + ioffst 
 					+ icol * a_dim1], &ilda, &extra, &
@@ -762,11 +759,11 @@ JKL, JKU
 
    Computing MIN */
 		    i__2 = *m, i__3 = *n + jkl;
-		    iendch = min(i__2,i__3) - 1;
+		    iendch = SUPERLU_MIN(i__2,i__3) - 1;
 /* Computing MIN */
 		    i__2 = *m + jku;
 		    i__3 = 1 - jkl;
-		    for (jc = min(i__2,*n) - 1; jc >= i__3; --jc) {
+		    for (jc = SUPERLU_MIN(i__2,*n) - 1; jc >= i__3; --jc) {
 			extra = 0.f;
 			angle = slarnd_slu(&c__1, &iseed[1]) * 
 				6.2831853071795864769252867663f;
@@ -774,11 +771,11 @@ JKL, JKU
 			s = sin(angle);
 /* Computing MAX */
 			i__2 = 1, i__4 = jc - jku + 1;
-			irow = max(i__2,i__4);
+			irow = SUPERLU_MAX(i__2,i__4);
 			if (jc > 0) {
 /* Computing MIN */
 			    i__2 = *m, i__4 = jc + jkl + 1;
-			    il = min(i__2,i__4) + 1 - irow;
+			    il = SUPERLU_MIN(i__2,i__4) + 1 - irow;
 			    L__1 = jc + jkl < *m;
 			    slarot_slu(&c_false, &c_false, &L__1, &il, &c, &s, &
 				    a[irow - iskew * jc + ioffst + jc * 
@@ -797,10 +794,10 @@ JKL, JKU
 				slartg_slu(&a[jch - iskew * ic + ioffst + ic * 
 					a_dim1], &extra, &c, &s, &dummy);
 			    }
-			    ic = max(1,ic);
+			    ic = SUPERLU_MAX(1,ic);
 /* Computing MIN */
 			    i__5 = *n - 1, i__6 = jch + jku;
-			    icol = min(i__5,i__6);
+			    icol = SUPERLU_MIN(i__5,i__6);
 			    iltemp = jch + jku < *n;
 			    temp = 0.f;
 			    i__5 = icol + 2 - ic;
@@ -812,7 +809,7 @@ JKL, JKU
 					* a_dim1], &temp, &c, &s, &dummy);
 /* Computing MIN */
 				i__5 = iendch, i__6 = jch + jkl + jku;
-				il = min(i__5,i__6) + 2 - jch;
+				il = SUPERLU_MIN(i__5,i__6) + 2 - jch;
 				extra = 0.f;
 				L__1 = jch + jkl + jku <= iendch;
 				slarot_slu(&c_false, &c_true, &L__1, &il, &c, &s,
@@ -840,11 +837,11 @@ L, M )
 
    Computing MIN */
 		    i__3 = *n, i__4 = *m + jku;
-		    iendch = min(i__3,i__4) - 1;
+		    iendch = SUPERLU_MIN(i__3,i__4) - 1;
 /* Computing MIN */
 		    i__3 = *n + jkl;
 		    i__4 = 1 - jku;
-		    for (jr = min(i__3,*m) - 1; jr >= i__4; --jr) {
+		    for (jr = SUPERLU_MIN(i__3,*m) - 1; jr >= i__4; --jr) {
 			extra = 0.f;
 			angle = slarnd_slu(&c__1, &iseed[1]) * 
 				6.2831853071795864769252867663f;
@@ -852,11 +849,11 @@ L, M )
 			s = sin(angle);
 /* Computing MAX */
 			i__3 = 1, i__2 = jr - jkl + 1;
-			icol = max(i__3,i__2);
+			icol = SUPERLU_MAX(i__3,i__2);
 			if (jr > 0) {
 /* Computing MIN */
 			    i__3 = *n, i__2 = jr + jku + 1;
-			    il = min(i__3,i__2) + 1 - icol;
+			    il = SUPERLU_MIN(i__3,i__2) + 1 - icol;
 			    L__1 = jr + jku < *n;
 			    slarot_slu(&c_true, &c_false, &L__1, &il, &c, &s, &a[
 				    jr - iskew * icol + ioffst + icol * 
@@ -875,10 +872,10 @@ L, M )
 				slartg_slu(&a[ir - iskew * jch + ioffst + jch * 
 					a_dim1], &extra, &c, &s, &dummy);
 			    }
-			    ir = max(1,ir);
+			    ir = SUPERLU_MAX(1,ir);
 /* Computing MIN */
 			    i__5 = *m - 1, i__6 = jch + jkl;
-			    irow = min(i__5,i__6);
+			    irow = SUPERLU_MIN(i__5,i__6);
 			    iltemp = jch + jkl < *m;
 			    temp = 0.f;
 			    i__5 = irow + 2 - ir;
@@ -890,7 +887,7 @@ L, M )
 					 a_dim1], &temp, &c, &s, &dummy);
 /* Computing MIN */
 				i__5 = iendch, i__6 = jch + jkl + jku;
-				il = min(i__5,i__6) + 2 - jch;
+				il = SUPERLU_MIN(i__5,i__6) + 2 - jch;
 				extra = 0.f;
 				L__1 = jch + jkl + jku <= iendch;
 				slarot_slu(&c_true, &c_true, &L__1, &il, &c, &s, 
@@ -933,10 +930,10 @@ L, M )
 		    for (jc = 1; jc <= i__4; ++jc) {
 /* Computing MAX */
 			i__2 = 1, i__3 = jc - k;
-			irow = max(i__2,i__3);
+			irow = SUPERLU_MAX(i__2,i__3);
 /* Computing MIN */
 			i__2 = jc + 1, i__3 = k + 2;
-			il = min(i__2,i__3);
+			il = SUPERLU_MIN(i__2,i__3);
 			extra = 0.f;
 			temp = a[jc - iskew * (jc + 1) + ioffg + (jc + 1) * 
 				a_dim1];
@@ -950,7 +947,7 @@ L, M )
 				ilda, &extra, &temp);
 /* Computing MIN */
 			i__3 = k, i__5 = *n - jc;
-			i__2 = min(i__3,i__5) + 1;
+			i__2 = SUPERLU_MIN(i__3,i__5) + 1;
 			slarot_slu(&c_true, &c_true, &c_false, &i__2, &c, &s, &a[
 				(1 - iskew) * jc + ioffg + jc * a_dim1], &
 				ilda, &temp, &dummy);
@@ -968,19 +965,19 @@ L, M )
 			    temp = a[jch - iskew * (jch + 1) + ioffg + (jch + 
 				    1) * a_dim1];
 			    i__3 = k + 2;
-			    r__1 = -(doublereal)s;
+			    r__1 = -(double)s;
 			    slarot_slu(&c_true, &c_true, &c_true, &i__3, &c, &
 				    r__1, &a[(1 - iskew) * jch + ioffg + jch *
 				     a_dim1], &ilda, &temp, &extra);
 /* Computing MAX */
 			    i__3 = 1, i__5 = jch - k;
-			    irow = max(i__3,i__5);
+			    irow = SUPERLU_MAX(i__3,i__5);
 /* Computing MIN */
 			    i__3 = jch + 1, i__5 = k + 2;
-			    il = min(i__3,i__5);
+			    il = SUPERLU_MIN(i__3,i__5);
 			    extra = 0.f;
 			    L__1 = jch > k;
-			    r__1 = -(doublereal)s;
+			    r__1 = -(double)s;
 			    slarot_slu(&c_false, &L__1, &c_true, &il, &c, &r__1, 
 				    &a[irow - iskew * jch + ioffg + jch * 
 				    a_dim1], &ilda, &extra, &temp);
@@ -1003,7 +1000,7 @@ te that
 			irow = ioffst - iskew * jc;
 /* Computing MIN */
 			i__2 = *n, i__3 = jc + uub;
-			i__4 = min(i__2,i__3);
+			i__4 = SUPERLU_MIN(i__2,i__3);
 			for (jr = jc; jr <= i__4; ++jr) {
 			    a[jr + irow + jc * a_dim1] = a[jc - iskew * jr + 
 				    ioffg + jr * a_dim1];
@@ -1049,20 +1046,20 @@ te that
 		    for (jc = *n - 1; jc >= 1; --jc) {
 /* Computing MIN */
 			i__4 = *n + 1 - jc, i__2 = k + 2;
-			il = min(i__4,i__2);
+			il = SUPERLU_MIN(i__4,i__2);
 			extra = 0.f;
 			temp = a[(1 - iskew) * jc + 1 + ioffg + jc * a_dim1];
 			angle = slarnd_slu(&c__1, &iseed[1]) * 
 				6.2831853071795864769252867663f;
 			c = cos(angle);
-			s = -(doublereal)sin(angle);
+			s = -(double)sin(angle);
 			L__1 = *n - jc > k;
 			slarot_slu(&c_false, &c_true, &L__1, &il, &c, &s, &a[(1 
 				- iskew) * jc + ioffg + jc * a_dim1], &ilda, &
 				temp, &extra);
 /* Computing MAX */
 			i__4 = 1, i__2 = jc - k + 1;
-			icol = max(i__4,i__2);
+			icol = SUPERLU_MAX(i__4,i__2);
 			i__4 = jc + 2 - icol;
 			slarot_slu(&c_true, &c_false, &c_true, &i__4, &c, &s, &a[
 				jc - iskew * icol + ioffg + icol * a_dim1], &
@@ -1086,7 +1083,7 @@ te that
 				    a_dim1], &ilda, &extra, &temp);
 /* Computing MIN */
 			    i__3 = *n + 1 - jch, i__5 = k + 2;
-			    il = min(i__3,i__5);
+			    il = SUPERLU_MIN(i__3,i__5);
 			    extra = 0.f;
 			    L__1 = *n - jch > k;
 			    slarot_slu(&c_false, &c_true, &L__1, &il, &c, &s, &a[
@@ -1110,7 +1107,7 @@ te that
 			irow = ioffst - iskew * jc;
 /* Computing MAX */
 			i__2 = 1, i__4 = jc - uub;
-			i__1 = max(i__2,i__4);
+			i__1 = SUPERLU_MAX(i__2,i__4);
 			for (jr = jc; jr >= i__1; --jr) {
 			    a[jr + irow + jc * a_dim1] = a[jc - iskew * jr + 
 				    ioffg + jr * a_dim1];
@@ -1260,7 +1257,7 @@ te that
 	    for (j = 1; j <= i__1; ++j) {
 /* Computing MIN */
 		i__2 = j + llb;
-		for (i = min(i__2,*m); i >= 1; --i) {
+		for (i = SUPERLU_MIN(i__2,*m); i >= 1; --i) {
 		    a[i - j + uub + 1 + j * a_dim1] = a[i + j * a_dim1];
 /* L370: */
 		}
@@ -1271,7 +1268,7 @@ te that
 	    for (j = uub + 2; j <= i__1; ++j) {
 /* Computing MIN */
 		i__4 = j + llb;
-		i__2 = min(i__4,*m);
+		i__2 = SUPERLU_MIN(i__4,*m);
 		for (i = j - uub; i <= i__2; ++i) {
 		    a[i - j + uub + 1 + j * a_dim1] = a[i + j * a_dim1];
 /* L390: */
@@ -1318,9 +1315,9 @@ te that
 /* Computing MAX   
    Computing MIN */
 		i__3 = ir1, i__5 = ir2 - jc;
-		i__2 = 1, i__4 = min(i__3,i__5);
+		i__2 = 1, i__4 = SUPERLU_MIN(i__3,i__5);
 		i__6 = *lda;
-		for (jr = max(i__2,i__4); jr <= i__6; ++jr) {
+		for (jr = SUPERLU_MAX(i__2,i__4); jr <= i__6; ++jr) {
 		    a[jr + jc * a_dim1] = 0.f;
 /* L440: */
 		}
