@@ -1,35 +1,32 @@
 /*  -- translated by f2c (version 19940927).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
 */
 
+#include <math.h>
+#include <stdbool.h>
+#include <stdlib.h>
 #include <string.h>
-#include "f2c.h"
+#include "../../SRC/slu_ddefs.h"
 
 /* Table of constant values */
 
-/* Subroutine */ int zlatb4_slu(char *path, integer *imat, integer *m, integer *
-	n, char *type, integer *kl, integer *ku, doublereal *anorm, integer *
-	mode, doublereal *cndnum, char *dist)
+/* Subroutine */ int zlatb4_slu(char *path, int *imat, int *m, int *
+	n, char *type, int *kl, int *ku, double *anorm, int *
+	mode, double *cndnum, char *dist)
 {
     /* Initialized data */
 
-    static logical first = TRUE_;
+    static bool first = true;
 
     /* System generated locals */
-    integer i__1;
-
-    /* Builtin functions */
-    double sqrt(doublereal);
-
+    int i__1;
 
     /* Local variables */
-    static doublereal badc1, badc2, large, small;
+    static double badc1, badc2, large, small;
     static char c2[2];
-    extern /* Subroutine */ int dlabad_slu(doublereal *, doublereal *);
-    extern doublereal dmach(char *);
-    static integer mat;
-    static doublereal eps;
+    extern /* Subroutine */ int dlabad_slu(double *, double *);
+    extern double dmach(char *);
+    static int mat;
+    static double eps;
 
 
 /*  -- LAPACK test routine (version 2.0) --   
@@ -96,7 +93,7 @@
        Set some constants for use in the subroutine. */
 
     if (first) {
-	first = FALSE_;
+	first = false;
 	eps = dmach("Precision");
 	badc2 = .1 / eps;
 	badc1 = sqrt(badc2);
@@ -138,19 +135,19 @@
 	    *kl = 0;
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	} else if (*imat == 3) {
 /* Computing MAX */
 	    i__1 = *m - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 	    *ku = 0;
 	} else {
 /* Computing MAX */
 	    i__1 = *m - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	}
 
 /*        Set the condition number and norm. */
@@ -188,19 +185,19 @@
 	    *kl = 0;
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	} else if (*imat == 3) {
 /* Computing MAX */
 	    i__1 = *m - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 	    *ku = 0;
 	} else {
 /* Computing MAX */
 	    i__1 = *m - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	}
 
 /*        Set the condition number and norm. */
@@ -300,7 +297,7 @@ x.
 	} else {
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 	}
 	*ku = *kl;
 
@@ -394,13 +391,13 @@ x.
 	} else if (*imat < 0) {
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *kl = max(i__1,0);
+	    *kl = SUPERLU_MAX(i__1,0);
 	    *ku = 0;
 	} else {
 	    *kl = 0;
 /* Computing MAX */
 	    i__1 = *n - 1;
-	    *ku = max(i__1,0);
+	    *ku = SUPERLU_MAX(i__1,0);
 	}
 
 /*        Set the condition number and norm. */
