@@ -1,4 +1,4 @@
-/*! \file
+/*
 Copyright (c) 2003, The Regents of the University of California, through
 Lawrence Berkeley National Laboratory (subject to receipt of any required 
 approvals from U.S. Dept. of Energy) 
@@ -16,66 +16,49 @@ at the top-level directory.
  * October 15, 2003
  *
  */
+
+/*! \file
+ * ZGST02 computes the residual for a solution of a system of linear
+ * equations  A*x = b  or  A'*x = b:
+ *    RESID = norm(B - A*X) / ( norm(A) * norm(X) * EPS ),
+ * where EPS is the machine epsilon.
+ *
+ * \ingroup TestingZ
+ */
+
 #include "slu_zdefs.h"
 
+/*!
+ * ZGST02 computes the residual for a solution of a system of linear
+ * equations  A*x = b  or  A'*x = b:
+ *    RESID = norm(B - A*X) / ( norm(A) * norm(X) * EPS ),
+ * where EPS is the machine epsilon.
+ *
+ * \param[in] trans   Specifies the form of the system of equations:
+ *                    = NOTRANS:  A *x = b
+ *                    = TRANS  :  A'*x = b, where A' is the transpose of A
+ *                    = CONJ   :  A'*x = b, where A' is the transpose of A
+ * \param[in] m       The number of rows of the matrix A.  M >= 0.
+ * \param[in] n       The number of columns of the matrix A.  N >= 0.
+ * \param[in] nrhs    The number of columns of B, the matrix of right hand sides.
+ *                    NRHS >= 0.
+ * \param[in] A       The original M x N sparse matrix A, dimension(LDA,N).
+ * \param[in] x       The computed solution vectors for the system of linear
+ *                    equations, dimension(LDX,NRHS).
+ * \param[in] ldx     The leading dimension of the array X.  If TRANS = NOTRANS,
+ *                    LDX >= max(1,N); if TRANS = TRANS or CONJ, LDX >= max(1,M).
+ * \param[in,out] b   On entry, the right hand side vectors for the system of
+ *                    linear equations.
+ *                    On exit, B is overwritten with the difference B - A*X.
+ *                    dimension(LDB,NRHS).
+ * \param[in] ldb     The leading dimension of the array B.  IF TRANS = NOTRANS,
+ *                    LDB >= max(1,M); if TRANS = TRANS or CONJ, LDB >= max(1,N).
+ * \param[out] resid  The maximum over the number of right hand sides of
+ *                    norm(B - A*X) / ( norm(A) * norm(X) * EPS ).
+ */
 int zgst02(trans_t trans, int m, int n, int nrhs, SuperMatrix *A,
-	      doublecomplex *x, int ldx, doublecomplex *b, int ldb, double *resid)
+           doublecomplex *x, int ldx, doublecomplex *b, int ldb, double *resid)
 {
-/*  
-    Purpose   
-    =======   
-
-    ZGST02 computes the residual for a solution of a system of linear   
-    equations  A*x = b  or  A'*x = b:   
-       RESID = norm(B - A*X) / ( norm(A) * norm(X) * EPS ),   
-    where EPS is the machine epsilon.   
-
-    Arguments   
-    =========   
-
-    TRANS   (input) trans_t
-            Specifies the form of the system of equations:   
-            = NOTRANS:  A *x = b   
-            = TRANS  :  A'*x = b, where A' is the transpose of A   
-            = CONJ   :  A'*x = b, where A' is the transpose of A   
-
-    M       (input) INTEGER   
-            The number of rows of the matrix A.  M >= 0.   
-
-    N       (input) INTEGER   
-            The number of columns of the matrix A.  N >= 0.   
-
-    NRHS    (input) INTEGER   
-            The number of columns of B, the matrix of right hand sides.   
-            NRHS >= 0.
-	    
-    A       (input) SuperMatrix*, dimension (LDA,N)   
-            The original M x N sparse matrix A.   
-
-    X       (input) DOUBLE COMPLEX PRECISION array, dimension (LDX,NRHS)   
-            The computed solution vectors for the system of linear   
-            equations.   
-
-    LDX     (input) INTEGER   
-            The leading dimension of the array X.  If TRANS = NOTRANS,   
-            LDX >= max(1,N); if TRANS = TRANS or CONJ, LDX >= max(1,M).   
-
-    B       (input/output) DOUBLE COMPLEX PRECISION array, dimension (LDB,NRHS)   
-            On entry, the right hand side vectors for the system of   
-            linear equations.   
-            On exit, B is overwritten with the difference B - A*X.   
-
-    LDB     (input) INTEGER   
-            The leading dimension of the array B.  IF TRANS = NOTRANS,
-            LDB >= max(1,M); if TRANS = TRANS or CONJ, LDB >= max(1,N).
-	    
-    RESID   (output) DOUBLE PRECISION   
-            The maximum over the number of right hand sides of   
-            norm(B - A*X) / ( norm(A) * norm(X) * EPS ).   
-
-    =====================================================================
-*/
-
     /* Table of constant values */
     doublecomplex alpha = {-1., 0.0};
     doublecomplex beta  = {1., 0.0};
